# Descricao  
A classe Temposinc foi desenvolvida como uma ferramenta versatil para a obtencao e analise de dados de previsao do tempo. Com funcionalidades abrangentes, ela permite nao apenas a recuperacao das coordenadas de uma cidade, mas tambem a obtencao detalhada da previsao do tempo para os proximos 7 dias. Além disso, oferece recursos para calcular medias diarias, visualizar probabilidades de precipitacao de chuva atraves de graficos interativos e ate mesmo compartilhar essas informacoes meteorologicas por e-mail.  
# Funcionalidades  
-> Obter cordenadas de uma cidade.  
-> Obter previsao de tempo para os proximos sete dias.  
-> Obter a media de temperatura para os proximos sete dias.   
-> Obter previsao da temperatura atual.  
-> Obter previsao da temperatura por hora para os proxímos sete dias.  
-> Obter previsao da temperatura por hora de um dia em especifico.  
-> Elaboracao de um grafico que representa a probabilidade de ocorrencia de chuva nos proximos sete dias.  
-> Elaboração de um grafico que representa a probabilidade de ocorrencia de chuva por hora de um dia em especifico.  
-> Envio de dados climaticos por e-mail.  
